﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using System.Threading.Tasks;

namespace Modèle
{

    /// <summary>
    /// Interface Personne qui est la base des utilisateurs de l'application
    /// </summary>

    [DataContract]
    public abstract class Personne
    {
        /// <summary>
        /// String email d'une Personne
        /// </summary>
        [DataMember]
        public string Email { get; protected set; }
        /// <summary>
        /// String mot de passe d'une Personne
        /// </summary>
        [DataMember]
        public string MotDePasse { get; protected set; }  


        /// <summary>
        /// Constructeur d'une personne
        /// </summary>
        /// <param name="email">String l'email de la personne qui va être créée</param>
        /// <param name="mdp">String le mot de passe de la personne</param>
        public Personne(string email, string mdp)
        {
            Email = email;
            MotDePasse = mdp;
        }

        /// <summary>
        /// Création de la méthode abstraite ToString
        /// </summary>
        public abstract override string ToString();

        /// <summary>
        /// Création de la méthode abstraite AjouterRequin qui permet d'ajouter un Requin dans une ObservableCollection de Requin
        /// </summary>
        /// <param name="req">Requin le requin a ajouter</param>
        /// <param name="requins">ObservableCollection la où on ajoute le requin</param>
        public abstract void AjouterRequin(Requin req, ObservableCollection<Requin> requins);


        /// <summary>
        /// Création de la méthode abstraite ChangerMotDePasse qui permet de changer le mot de passe d'un personne
        /// </summary>
        /// <param name="nvMdp">String le nouveau mot de passe d'un Personne</param>
        public abstract void ChangerMotDePasse(string nvMdp);
    }
}
